==> aria2_0.9.0.orig.tar.gz: aria2-0.9.0/src/MetalinkEntry.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_METALINK_ENTRY_H_
#define _D_METALINK_ENTRY_H_

#include "common.h"
#include "MetalinkResource.h"
#include "Checksum.h"
#include <deque>

class MetalinkEntry {
public:
  string filename;
  string version;
  string language;
  string os;
  long long int size;
  Checksum checksum;
public:
  MetalinkResources resources;
public:
  MetalinkEntry();
  ~MetalinkEntry();

  MetalinkEntry& operator=(const MetalinkEntry& metalinkEntry) {
    if(this != &metalinkEntry) {
      this->filename = metalinkEntry.filename;
      this->version = metalinkEntry.version;
      this->language = metalinkEntry.language;
      this->os = metalinkEntry.os;
      this->size = metalinkEntry.size;
      this->checksum = metalinkEntry.checksum;
    }
    return *this;
  }

  void dropUnsupportedResource();

  void reorderResourcesByPreference();
  
  void setLocationPreference(const string& location, int preferenceToAdd);
};

typedef SharedHandle<MetalinkEntry> MetalinkEntryHandle;
typedef deque<MetalinkEntryHandle> MetalinkEntries;

#endif // _D_METALINK_ENTRY_H_

==> aria2_0.11.0.orig.tar.gz: aria2-0.11.0/src/MetalinkEntry.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_METALINK_ENTRY_H_
#define _D_METALINK_ENTRY_H_

#include "common.h"
#include "MetalinkResource.h"
#include "Checksum.h"
#include "MetalinkChunkChecksum.h"
#include <deque>

class MetalinkEntry {
public:
  string filename;
  string version;
  string language;
  string os;
  int64_t size;
  ChecksumHandle checksum;
public:
  MetalinkResources resources;
#ifdef ENABLE_MESSAGE_DIGEST
  MetalinkChunkChecksumHandle chunkChecksum;
#endif // ENABLE_MESSAGE_DIGEST
public:
  MetalinkEntry();
  ~MetalinkEntry();

  MetalinkEntry& operator=(const MetalinkEntry& metalinkEntry) {
    if(this != &metalinkEntry) {
      this->filename = metalinkEntry.filename;
      this->version = metalinkEntry.version;
      this->language = metalinkEntry.language;
      this->os = metalinkEntry.os;
      this->size = metalinkEntry.size;
      this->checksum = metalinkEntry.checksum;
#ifdef ENABLE_MESSAGE_DIGEST
      this->chunkChecksum = metalinkEntry.chunkChecksum;
#endif // ENABLE_MESSAGE_DIGEST
    }
    return *this;
  }

  void dropUnsupportedResource();

  void reorderResourcesByPreference();
  
  void setLocationPreference(const string& location, int preferenceToAdd);
};

typedef SharedHandle<MetalinkEntry> MetalinkEntryHandle;
typedef deque<MetalinkEntryHandle> MetalinkEntries;

#endif // _D_METALINK_ENTRY_H_
